@@ -55,3 +55,8 @@ var signatureExts = []string{
 var wasmExts = []string{
 	"wasm",
 }
+
+var rekorEntryTypes = []string{
+	"dsse", // first one is the default
+	"intoto",
+}
